==> activity-center-api-1.0.2-20160620.021236-21-sources.jar: cn/com/duiba/activity/center/api/dto/hdtool/HdtoolAppSpecifyDto.java <==
package cn.com.duiba.activity.center.api.dto.hdtool;

import java.io.Serializable;
import java.util.Date;

/**
 * 活动定向
 * 
 * @author houwen
 */
public class HdtoolAppSpecifyDto implements Serializable {
	private static final long serialVersionUID = -9049122687369769091L;

	public static final String HD_SHAKE = "shake";
	public static final String HD_SCRATCH_CARD = "scratchCard";
	public static final String HD_ITGER = "slotMachine";
	public static final String HD_TURNTABLE = "turntable";

	private Long id;
	private Long appId;
	private Long duibaHdtoolId;
	private String hdtoolType; // 引用OperatingActivityDTO.TYPE
	private Date gmtCreate;
	private Date gmtModified;

	public HdtoolAppSpecifyDto() {

	}

	public HdtoolAppSpecifyDto(Long id) {
		this.id = id;
		this.gmtModified = new Date();
	}

	public HdtoolAppSpecifyDto(boolean init4insert) {
		if (init4insert) {
			gmtCreate = new Date();
			gmtModified = new Date();
		}
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getDuibaHdtoolId() {
		return duibaHdtoolId;
	}

	public void setDuibaHdtoolId(Long duibaHdtoolId) {
		this.duibaHdtoolId = duibaHdtoolId;
	}

	public String getHdtoolType() {
		return hdtoolType;
	}

	public void setHdtoolType(String hdtoolType) {
		this.hdtoolType = hdtoolType;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

}

==> activity-center-api-1.2.13.8-20170120.081851-1-sources.jar: cn/com/duiba/activity/center/api/dto/hdtool/HdtoolAppSpecifyDto.java <==
package cn.com.duiba.activity.center.api.dto.hdtool;

import java.io.Serializable;
import java.util.Date;

/**
 * 活动定向
 * 
 * @author houwen
 */
public class HdtoolAppSpecifyDto implements Serializable {
	private static final long serialVersionUID = -9049122687369769091L;

	public static final String HD_SHAKE = "shake";
	public static final String HD_SCRATCH_CARD = "scratchCard";
	public static final String HD_ITGER = "slotMachine";
	public static final String HD_TURNTABLE = "turntable";
	public static final String HD_FLOP = "flop";
	public static final String HD_SMASHG = "smashg";

	private Long id;
	private Long appId;
	private Long duibaHdtoolId;
	private String hdtoolType; // 引用OperatingActivityDTO.TYPE
	private Date gmtCreate;
	private Date gmtModified;

	/**
	 * 
	 * Creates a new instance of HdtoolAppSpecifyDto.
	 *
	 */
	public HdtoolAppSpecifyDto() {

	}

	/**
	 * 
	 * Creates a new instance of HdtoolAppSpecifyDto.
	 *
	 * @param id
	 */
	public HdtoolAppSpecifyDto(Long id) {
		this.id = id;
		this.gmtModified = new Date();
	}

	/**
	 * 
	 * Creates a new instance of HdtoolAppSpecifyDto.
	 *
	 * @param init4insert
	 */
	public HdtoolAppSpecifyDto(boolean init4insert) {
		if (init4insert) {
			gmtCreate = new Date();
			gmtModified = new Date();
		}
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getDuibaHdtoolId() {
		return duibaHdtoolId;
	}

	public void setDuibaHdtoolId(Long duibaHdtoolId) {
		this.duibaHdtoolId = duibaHdtoolId;
	}

	public String getHdtoolType() {
		return hdtoolType;
	}

	public void setHdtoolType(String hdtoolType) {
		this.hdtoolType = hdtoolType;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

}
